<?php
/*
	Plugin Name: ARI Fancy Lightbox
	Plugin URI: http://wp-quiz.ari-soft.com/plugins/wordpress-fancy-lightbox.html
	Description: Full-featured lightbox plugin for WordPress.
	Version: 1.0.5
	Author: ARI Soft
	Author URI: http://www.ari-soft.com
	Text Domain: ari-fancy-lightbox
	Domain Path: /languages
	License: GPL2
 */

defined( 'ABSPATH' ) or die( 'Access forbidden!' );

define( 'ARIFANCYLIGHTBOX_EXEC_FILE', __FILE__ );
define( 'ARIFANCYLIGHTBOX_URL', plugin_dir_url( __FILE__ ) );
define( 'ARIFANCYLIGHTBOX_PATH', plugin_dir_path( __FILE__ ) );

if ( ! function_exists( 'ari_fancy_lightbox_init' ) ) {
    function ari_fancy_lightbox_init() {
        if ( defined( 'ARIFANCYLIGHTBOX_INITED' ) )
            return ;

        define( 'ARIFANCYLIGHTBOX_INITED', true );

        require_once ARIFANCYLIGHTBOX_PATH . 'includes/defines.php';
        require_once ARIFANCYLIGHTBOX_PATH . 'libraries/arisoft/loader.php';

        Ari_Loader::register_prefix( 'Ari_Fancy_Lightbox', ARIFANCYLIGHTBOX_PATH . 'includes' );

        $plugin = new \Ari_Fancy_Lightbox\Plugin(
            array(
                'class_prefix' => 'Ari_Fancy_Lightbox',

                'version' => ARIFANCYLIGHTBOX_VERSION,

                'path' => ARIFANCYLIGHTBOX_PATH,

                'url' => ARIFANCYLIGHTBOX_URL,

                'assets_url' => ARIFANCYLIGHTBOX_ASSETS_URL,

                'view_path' => ARIFANCYLIGHTBOX_PATH . 'includes/views/',

                'main_file' => __FILE__,
            )
        );
        $plugin->init();
    }
}

if ( ! function_exists( 'ari_fancy_lightbox_activation_check' ) ) {
    function ari_fancy_lightbox_activation_check() {
        $min_php_version = '5.4.0';
        $min_wp_version = '4.0.0';

        $current_wp_version = get_bloginfo( 'version' );
        $current_php_version = PHP_VERSION;

        $is_supported_php_version = version_compare( $current_php_version, $min_php_version, '>=' );
        $is_spl_installed = function_exists( 'spl_autoload_register' );
        $is_supported_wp_version = version_compare( $current_wp_version, $min_wp_version, '>=' );

        if ( ! $is_supported_php_version || ! $is_spl_installed || ! $is_supported_wp_version ) {
            deactivate_plugins( basename( ARIFANCYLIGHTBOX_EXEC_FILE ) );

            $recommendations = array();

            if ( ! $is_supported_php_version )
                $recommendations[] = sprintf(
                    __( 'update PHP version on your server from v. %s to at least v. %s', 'ari-fancy-lightbox' ),
                    $current_php_version,
                    $min_php_version
                );

            if ( ! $is_spl_installed )
                $recommendations[] = __( 'install PHP SPL extension', 'ari-fancy-lightbox' );

            if ( ! $is_supported_wp_version )
                $recommendations[] = sprintf(
                    __( 'update WordPress v. %s to at least v. %s', 'ari-fancy-lightbox' ),
                    $current_wp_version,
                    $min_wp_version
                );

            wp_die(
                sprintf(
                    __( '"ARI Fancy Lightbox" can not be activated. It requires PHP version 5.4.0+ with SPL extension and WordPress 4.0+.<br /><br /><b>Recommendations:</b> %s.<br /><br /><a href="%s" class="button button-primary">Back</a>', 'ari-fancy-lightbox' ),
                    join( ', ', $recommendations ),
                    get_dashboard_url()
                )
            );
        } else {
            add_option( 'ari_fancy_lightbox_redirect', true );

            ari_fancy_lightbox_init();
        }
    }
}

add_action( 'plugins_loaded', 'ari_fancy_lightbox_init' );
register_activation_hook( ARIFANCYLIGHTBOX_EXEC_FILE, 'ari_fancy_lightbox_activation_check' );
