<?php
namespace Ari\Wordpress;

use Ari\Utils\Array_Helper;

class Settings {
    protected $options = null;

    protected $default_settings = array(
    );

    protected $settings_group;

    protected $settings_name;

    static protected $instance = null;

    public static function instance() {
        $class = get_called_class();

        if ( is_null( $class::$instance ) ) {
            $class::$instance = new $class();
        }

        return $class::$instance;
    }

    protected function __construct() {

    }

    public function init() {
        register_setting(
            $this->settings_group,
            $this->settings_name,
            array( $this, 'sanitize' )
        );
    }

    public function options() {
        if ( ! is_null( $this->options ) )
            return $this->options;

        $this->options = get_option( $this->settings_name );

        return $this->options;
    }

    public function get_default_options() {
        return $this->default_settings;
    }

    public function full_options() {
        $current_options = $this->options();

        if ( ! is_array( $current_options ) )
            $current_options = array();

        $flat_default_settings = Array_Helper::to_flat_array( $this->default_settings );
        $flat_current_options = Array_Helper::to_flat_array( $current_options );

        $full_options = Array_Helper::to_complex_array(
            array_merge(
                $flat_default_settings,
                $flat_current_options
            )
        );

        return $full_options;
    }

    public function get_option( $name, $default = null ) {
        $options = $this->options();

        $complex_name = strpos( $name, '.' ) !== false;
        $val = $default;

        if ( $complex_name ) {
            $val = Array_Helper::value_by_path( $name, $options );

            if ( is_null( $val ) ) {
                $val = Array_Helper::value_by_path( $name, $this->default_settings );
                if ( is_null( $val ) )
                    $val = $default;
            }
        } else {
            if ( isset( $options[$name] ) ) {
                $val = $options[$name];
            } else if ( is_null( $default ) && isset( $this->default_settings[$name] ) ) {
                $val = $this->default_settings[$name];
            }
        }

        return $val;
    }

    public function sanitize( $input, $defaults = false ) {
        $new_input = array();

        if ( false === $defaults)
            $defaults = $this->default_settings;

        foreach ( $defaults as $key => $val ) {
            $type = gettype( $val );

            if ( 'boolean' == $type && ! isset( $input[$key] ) ) {
                $new_input[$key] = false;
            } else if ( 'array' == $type && ! isset( $input[$key] ) ) {
                $new_input[$key] = array();
            } else if ( isset( $input[$key] ) ) {
                $input_val = $input[$key];
                $filtered_val = null;
                switch ( $type ) {
                    case 'boolean':
                        $filtered_val = (bool) $input_val;
                        break;

                    case 'integer':
                        $filtered_val = intval( $input_val, 10 );
                        break;

                    case 'double':
                        $filtered_val = floatval( $input_val );
                        break;

                    case 'array':
                        $filtered_val = $input_val;
                        break;

                    case 'string':
                        $filtered_val = trim( $input_val );
                        break;
                }

                if ( ! is_null( $filtered_val) ) {
                    $new_input[$key] = $filtered_val;
                }
            }
        }

        return $new_input;
    }
}
